unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, FaxServer, Menus, ComCtrls, Grids, WinFax, ExtCtrls, ImgList,
  Buttons, Registry;

type
  TformMain = class(TForm)
    MainMenu1: TMainMenu;
    File1: TMenuItem;
    Options1: TMenuItem;
    N1: TMenuItem;
    StartItem: TMenuItem;
    StopItem: TMenuItem;
    StatusListBox: TListBox;
    FaxServer: TFaxService;
    SendFax: TMenuItem;
    SendFaxasfile1: TMenuItem;
    Panel1: TPanel;
    Panel2: TPanel;
    BoxTree: TTreeView;
    FaxGrid: TStringGrid;
    ImageList: TImageList;
    StartButton: TSpeedButton;
    StopButton: TSpeedButton;
    About1: TMenuItem;
    Exit1: TMenuItem;
    FaxCoverPage: TFaxCoverPage;
    procedure FormCreate(Sender: TObject);
    procedure Options1Click(Sender: TObject);
    procedure StartItemClick(Sender: TObject);
    procedure StopItemClick(Sender: TObject);
    procedure FaxServerStatusMessage(Severity: TStatusMessageSeverity;
      ErrorID: Cardinal; MsgStr: String);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure BoxTreeClick(Sender: TObject);
    procedure Install1Click(Sender: TObject);
    procedure SendFaxasfile1Click(Sender: TObject);
    procedure FaxGridDblClick(Sender: TObject);
    procedure FaxGridDrawCell(Sender: TObject; ACol, ARow: Integer;
      Rect: TRect; State: TGridDrawState);
    procedure About1Click(Sender: TObject);
    procedure Exit1Click(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    procedure RefreshFaxDrid;
  end;

var
  formMain: TformMain;

  // preferences
  ActiveDeviceID: integer;
  ArchiveDirectoryOut: string;
  ArchiveDirectoryIn: string;
  AppDir: string;

  procedure ReadSettings;
  procedure WriteSettings;

implementation

uses Options, SendFax, About;

{$R *.DFM}

procedure TformMain.FormCreate(Sender: TObject);
begin
   ReadSettings;

   FaxServer.ActiveDeviceID := ActiveDeviceID;
   FaxServer.Connect('');

   FaxServer.FaxDocList.LoadFromFile('Faxes.dat');

   BoxTree.TopItem.Selected := True;
   RefreshFaxDrid;
end;

procedure TformMain.Options1Click(Sender: TObject);
begin
   formOptions := TformOptions.Create(self);

   try
      formOptions.ShowModal;
   finally
      formOptions.Free;
      formOptions := nil;
   end;

end;

procedure TformMain.RefreshFaxDrid;
Var
   BoxID, i, rows: integer;
   fax: TFaxDocument;
begin
   if BoxTree.Selected=nil then
      exit;

   if BoxTree.Selected.Text = 'All' then BoxID := DWORD(-1)
   else if BoxTree.Selected.Text = 'Incoming' then BoxID := JT_RECEIVE
   else if BoxTree.Selected.Text = 'Outgoing' then BoxID := JT_SEND
   else if BoxTree.Selected.Text = 'Damaged' then BoxID := JT_FAIL_RECEIVE;

   rows := 1;
   FaxGrid.Cells[0, rows] := ''; FaxGrid.Cells[1, rows] := ''; FaxGrid.Cells[2, rows] := '';
   FaxGrid.Cells[3, rows] := ''; FaxGrid.Cells[4, rows] := ''; FaxGrid.Cells[5, rows] := '';
   FaxGrid.Cells[6, rows] := ''; FaxGrid.Cells[7, rows] := '';

   rows := 0;   
   for i:=0 to FaxServer.FaxDocList.Count-1 do
   begin
      fax := TFaxDocument(FaxServer.FaxDocList.Items[i]);

      if (BoxID = -1) or (fax.JobType = BoxID) Then
      begin
         Inc(rows);
         FaxGrid.Cells[0, rows] := IntToStr(i);
         FaxGrid.Cells[1, rows] := IntToStr(fax.JobType);
         FaxGrid.Cells[2, rows] := IntToStr(fax.QueueStatus);
         FaxGrid.Cells[3, rows] := fax.RecipientNumber;
         FaxGrid.Cells[4, rows] := fax.Tsid;
         FaxGrid.Cells[5, rows] := IntToStr(fax.PageCount);
         FaxGrid.Cells[6, rows] := IntToStr(fax.Size);
         FaxGrid.Cells[7, rows] := ExtractFileName(fax.TIFFFileName);
      end;
   end;

   FaxGrid.RowCount := rows+1;
   if FaxGrid.RowCount = 1 then
      FaxGrid.RowCount := 2;

   FaxGrid.FixedRows := 1;
   FaxGrid.Cells[0, 0] := 'ID';
   FaxGrid.Cells[1, 0] := 'Job';
   FaxGrid.Cells[2, 0] := 'Que';
   FaxGrid.Cells[3, 0] := 'Recipient';
   FaxGrid.Cells[4, 0] := 'Fax ID';
   FaxGrid.Cells[5, 0] := 'Page count';
   FaxGrid.Cells[6, 0] := 'Fax Size';
   FaxGrid.Cells[7, 0] := 'TIFF File';
end;

procedure TformMain.StartItemClick(Sender: TObject);
begin
   FaxServer.ArchiveDirIn := ArchiveDirectoryIn;
   FaxServer.ArchiveDirOut := ArchiveDirectoryOut;

   FaxServer.StartEventWaiting;

   StartItem.Enabled := False;
   StopItem.Enabled := True;
   StopButton.Enabled := True;
   StartButton.Enabled := False;

   FaxCoverPage.CoverPageName := AppDir+'confdent.cov';
end;

procedure TformMain.StopItemClick(Sender: TObject);
begin
   FaxServer.StopEventWaiting;
   StartItem.Enabled := True;
   StopItem.Enabled := False;
   StopButton.Enabled := False;
   StartButton.Enabled := True;
end;

procedure TformMain.FaxServerStatusMessage(
  Severity: TStatusMessageSeverity; ErrorID: Cardinal; MsgStr: String);
Var
   Msg: string;
begin
   Msg := '<'+DateTimeToStr (Now)+'> ';
   case Severity of
      smsError: StatusListBox.Items.Add(Msg+'ERROR: '+MsgStr);
      smsStatus: StatusListBox.Items.Add(Msg+MsgStr);
      smsDebug: StatusListBox.Items.Add(Msg+MsgStr);
   end;
end;

procedure TformMain.FormClose(Sender: TObject; var Action: TCloseAction);
begin
   WriteSettings;
   FaxServer.FaxDocList.SaveToFile('Faxes.dat');
   Action := caFree;
end;

procedure TformMain.BoxTreeClick(Sender: TObject);
begin
   RefreshFaxDrid;
end;

procedure TformMain.Install1Click(Sender: TObject);
begin
   FaxServer.EnableRoutingExtension(True);
end;

procedure TformMain.SendFaxasfile1Click(Sender: TObject);
begin
   formSendFax := TformSendFax.Create(self);

   try
      formSendFax.ShowModal;
   finally
      formSendFax.Free;
      formSendFax := nil;
   end;
end;

procedure TformMain.FaxGridDblClick(Sender: TObject);
Var
   doc: TFaxDocument;
begin
   if FaxGrid.Row=0 then
      exit;
   doc := TFaxDocument(FaxServer.FaxDocList.Items[StrToInt(FaxGrid.Cells[0, FaxGrid.Row])]);
   doc.ShowFax(handle);
end;

procedure TformMain.FaxGridDrawCell(Sender: TObject; ACol, ARow: Integer;
  Rect: TRect; State: TGridDrawState);
Var
   Image: TBitmap;
begin
   Image := TBitmap.Create;
   try
      if (ACol=1) and (ARow<>0) Then
      begin
         if FaxGrid.Cells[ACol, ARow]<>'' then
         begin
            ImageList.GetBitmap(StrToInt(FaxGrid.Cells[ACol, ARow]), Image);
            FaxGrid.Canvas.Draw(Rect.Left, Rect.Top, Image);
         end;
      end;
   finally
      Image.Free;
   end;
end;

procedure TformMain.About1Click(Sender: TObject);
Var
   formAbout: TAboutBox;
begin
   formAbout := TAboutBox.Create(self);

   try
      formAbout.ShowModal;
   finally
      formAbout.Free;
      formAbout := nil;
   end;
end;

procedure ReadSettings;
Var
   RegKey: TRegistry;
Begin
   RegKey := TRegistry.Create;
   RegKey.RootKey := HKEY_CURRENT_USER;
   RegKey.OpenKey('Software', True);
   RegKey.OpenKey('PF', True);
   RegKey.OpenKey('FaxDemo 1.0', True);

   if RegKey.ValueExists('ArchiveDirectoryIn') then
      ArchiveDirectoryIn := RegKey.ReadString('ArchiveDirectoryIn');

   if RegKey.ValueExists('ArchiveDirectoryOut') then
      ArchiveDirectoryOut := RegKey.ReadString('ArchiveDirectoryOut');

   if RegKey.ValueExists('ActiveDeviceID') then
      ActiveDeviceID := RegKey.ReadInteger('ActiveDeviceID');

   RegKey.CloseKey;
   RegKey.Free;
End;

procedure WriteSettings;
Var
   RegKey: TRegistry;
Begin
   RegKey := TRegistry.Create;
   RegKey.RootKey := HKEY_CURRENT_USER;
   RegKey.OpenKey('Software', True);
   RegKey.OpenKey('PF', True);
   RegKey.OpenKey('FaxDemo 1.0', True);

   RegKey.WriteString('ArchiveDirectoryIn', ArchiveDirectoryIn);
   RegKey.WriteString('ArchiveDirectoryOut', ArchiveDirectoryOut);
   RegKey.WriteInteger('ActiveDeviceID', ActiveDeviceID);

   RegKey.CloseKey;
   RegKey.Free;
End;

procedure TformMain.Exit1Click(Sender: TObject);
begin
   Close;
end;

function SetFullDir (dir : string): string;
Begin
   Result := Dir;
   if Copy(Dir, Length(Dir), 1) <> '\' then
      Result := Result + '\';
End;

initialization
   ActiveDeviceID := 0;
   // Default archive directory settings for Windows 2000:
   ArchiveDirectoryOut := 'C:\Documents and Settings\All Users\Documents\My Faxes\Sent Faxes';
   ArchiveDirectoryIn := 'C:\Documents and Settings\All Users\Documents\My Faxes\Received Faxes';
   AppDir            := SetFullDir(ExtractFileDir(Application.ExeName));
end.
